@@ -113,6 +113,103 @@ class RelationalDbHelper(BaseSqlHelper, ABC):
         # 组装成page包装类 最终转为 dict 类型 为转换json
         return Page(records=records, current=page_num, page_size=page_size, total=total.get("total")).__dict__
 
+    def sync_insert_data(self, table_name: str, data):
+        """
+        对于插入接口的整合，不需要考虑是单条插入还是多条插入，自动区分
+        :param table_name:
+        :param data:
+        :return:
+        """
+        if isinstance(data, list):
+            if len(data) == 1:
+                return self.sync_insert_one_data(table_name, data[0])
+            else:
+                return self.sync_insert_many_data(table_name, data)
+        elif isinstance(data, dict):
+            return self.sync_insert_one_data(table_name, data)
+
+    def sync_insert_one_data(self, table_name: str, data: dict):
+        """
+        新增记录插入
+        :param table_name: 表名
+        :param data: 待插入数据
+        :return:
+        """
+        insert_sql = self.prepare_insert_sql(table_name, data)
+        param = []
+        for v in data.values():
+            if isinstance(v, DBFunction):
+                param.append(v.value)
+            else:
+                param.append(v)
+        rs = self.sync_execute_sql(insert_sql, param)
+        return rs
+
+    def sync_insert_many_data(self, table_name: str, data: list):
+        """
+        批量插入
+        :param table_name:
+        :param data:
+        :return:
+        """
+        insert_sql = self.prepare_insert_sql(table_name, data.__getitem__(0))
+        return self.sync_executemany_sql(insert_sql, data)
+
+    def sync_update_data(self, condition_wrapper: ConditionWrapper, data: dict):
+        """
+        按条件更新
+        :param condition_wrapper: 更新条件
+        :param data:更新值
+        :return:
+        """
+        update_sql, values = self.prepare_update_sql(condition_wrapper, data)
+        rs = self.sync_execute_sql(update_sql, values)
+        return rs
+
+    def sync_delete_data(self, condition_wrapper: ConditionWrapper):
+        """
+        按条件删除
+        :param condition_wrapper: 删除条件
+        :return:
+        """
+        delete_sql, values = self.prepare_delete_sql(condition_wrapper)
+        rs = self.sync_execute_sql(delete_sql, values)
+        return rs
+
+    def sync_fetchone_data(self, condition_wrapper: ConditionWrapper):
+        """
+        查询单条数据
+        :param condition_wrapper:  查询条件信息
+        :return:
+        """
+        query_sql, values = self.prepare_query_sql(condition_wrapper)
+        return self.sync_execute_fetchone(query_sql, values)
+
+    def sync_fetchall_data(self, condition_wrapper: ConditionWrapper):
+        """
+        查询多条数据
+        :param condition_wrapper: 查询条件信息
+        :return:
+        """
+        query_sql, values = self.prepare_query_sql(condition_wrapper)
+        return self.sync_execute_fetchall(query_sql, values)
+
+    def sync_fetchall_page(self, condition_wrapper: ConditionWrapper, page_num=1, page_size=10):
+        """
+        分页查询多条数据
+        :param condition_wrapper:
+        :param page_num: 当前页码
+        :param page_size: 每页数量
+        :return:
+        """
+        page_sql, values, count_sql = self.prepare_page_sql(condition_wrapper, page_num, page_size)
+        # 查询分页记录
+        records = self.sync_execute_fetchall(page_sql, values)
+        # 查询记录数量
+        total = self.sync_execute_fetchone(count_sql, values)
+        # 组装成page包装类 最终转为 dict 类型 为转换json
+        return Page(records=records, current=page_num, page_size=page_size, total=total.get("total")).__dict__
+
     def prepare_insert_sql(self, table_name: str, item: dict):
         """
         组装插入sql
@@ -126,7 +223,7 @@ class RelationalDbHelper(BaseSqlHelper, ABC):
         # placeholder_str = ','.join('%s' for v in range(len(item)))
         placeholder_items = []
         for v in item.values():
-            if isinstance(v,DBFunction):
+            if isinstance(v, DBFunction):
                 placeholder_items.append(v.function_body)
             else:
                 placeholder_items.append("%s")
@@ -156,7 +253,7 @@ class RelationalDbHelper(BaseSqlHelper, ABC):
         column_sql = ','.join(placeholder_items)
         condition_sql, values = self.prepare_condition_sql(condition_wrapper.conditions)
         update_sql = f"UPDATE {condition_wrapper.table} SET {column_sql} WHERE {condition_sql}"
-        return update_sql, value_items+values
+        return update_sql, value_items + values
 
     def prepare_delete_sql(self, condition_wrapper: ConditionWrapper):
         """
@@ -262,10 +359,7 @@ class RelationalDbHelper(BaseSqlHelper, ABC):
             col = col.upper().replace("AS", "").strip().split(" ")
             cols.append(col[-1].strip())
         # 组装分页查询语句，需要依据页码计算 起始索引
-        page_sql = f"SELECT {','.join(cols)} FROM ({query_sql}) cs OFFSET {Page.skip(page_num,page_size)} LIMIT {page_size}"
+        page_sql = f"SELECT {','.join(cols)} FROM ({query_sql}) cs OFFSET {Page.skip(page_num, page_size)} LIMIT {page_size}"
         # 组装查询数量语句
         count_sql = f"SELECT count(1) total FROM ({query_sql}) cs"
         return page_sql, values, count_sql
-
-
-
